@@ -3,6 +3,7 @@ from Crypto.Cipher import AES
 from Crypto.Hash import SHA256
 from base64 import b64encode, b64decode
 from websocket._exceptions import WebSocketConnectionClosedException
+from datetime import datetime
 import websocket
 import json
 
@@ -39,6 +40,7 @@ class Chat:
             "hashtags": hashtags,
             "nonce": nonce,
             "tag": tag,
+            "sendtime": datetime.now().strftime("%Y/%m/%d %H:%M:%S"),
             "bot": True
         }
         if self.sock_connected:
